@@ -1,43 +1,43 @@
 #' @title Puchwein algorithm for calibration sampling
 #'
 #' @description
-#' Select calibration samples from multivariate data using the Puchwein 
+#' Select calibration samples from multivariate data using the Puchwein
 #' algorithm
 #' @usage
-#' puchwein(X, 
-#'          pc = 0.95, 
-#'          k, 
-#'          min.sel, 
+#' puchwein(X,
+#'          pc = 0.95,
+#'          k,
+#'          min.sel,
 #'          details = FALSE,
-#'          .center = TRUE, 
+#'          .center = TRUE,
 #'          .scale = FALSE)
 #' @param X a matrix from which the calibration samples are to be selected
 #' (optionally a data frame that can be coerced to a numerical matrix).
 #' @param pc the number of principal components retained in the computation of
-#' the distance in the standardized Principal Component space (Mahalanobis 
+#' the distance in the standardized Principal Component space (Mahalanobis
 #' distance).
 #' If `pc < 1`, the number of principal components kept corresponds to the
 #' number of components
-#' explaining at least (`pc * 100`) percent of the total variance 
+#' explaining at least (`pc * 100`) percent of the total variance
 #' (default = 0.95 as in the Puchwein paper).
 #' @param k the initial limiting distance parameter, if not specified (default),
 #' set to 0.2. According to Puchwein, a good starting value for the limiting
 #' distance is \eqn{d_{ini} = k(p-2)} where \eqn{p} is the number of
 #' principal components
-#' @param min.sel minimum number of samples to select for calibration 
+#' @param min.sel minimum number of samples to select for calibration
 #' (default = 5).
 #' @param details logical value, if `TRUE`, adds a component in the output list
 #' with the indices of the objects kept in each loop (default to `FALSE`).
-#' @param .center logical value indicating whether the input matrix should be
+#' @param .center logical value indicating whether the input matrix must be
 #' centered before Principal Component.
 #' Analysis. Default set to TRUE.
-#' @param .scale logical value indicating whether the input matrix should be
+#' @param .scale logical value indicating whether the input matrix must be
 #' scaled before Principal Component
 #' Analysis. Default set to FALSE.
 #' @author Antoine Stevens
 #' @return a `list` with components:
 #' \itemize{
-#'  \item{'`model`'}{ indices of the observations (row indices of the input 
+#'  \item{'`model`'}{ indices of the observations (row indices of the input
 #'  data)
 #'  selected for calibration}
 #'  \item{'`test`'}{ indices of the remaining observations (row indices of the
@@ -48,7 +48,7 @@
 #'  theoretical sum of leverages of the selected samples}
 #'  \item{'`leverage`'}{ data frame giving the observed and theoretical
 #'  cumulative sums of leverage of the points selected in each loop}
-#'  \item{'`details`'}{ list with the indices of the observations kept in each 
+#'  \item{'`details`'}{ list with the indices of the observations kept in each
 #'  loop}
 #' }
 #' @examples
@@ -62,11 +62,10 @@
 #' par(mar = c(4, 5, 2, 2))
 #' plot(sel$leverage$loop, sel$leverage$diff,
 #'   type = "l",
-#'   xlab = "# loops", 
+#'   xlab = "# loops",
 #'   ylab = "Difference between theoretical and \n observed sum of leverages"
 #' )
 #' par(opar)
-#' 
 #' @references
 #' Puchwein, G., 1988. Selection of calibration samples for near-infrared
 #' spectrometry by factor analysis of spectra. Analytical Chemystry 60, 569-573.
@@ -80,9 +79,9 @@
 #' eliminating similar samples using the Mahalanobis distance.
 #' It starts by performing a PCA on the input matrix and extracts the score
 #' matrix truncated to \eqn{A}, the number of principal components. The score
-#' matrix is then normalized to unit variance and the Euclidean distance of each 
-#' sample to the centre of the data is computed, which is identical to the 
-#' Mahalanobis distance \eqn{H}. Additionally, the Mahalanobis distances between 
+#' matrix is then normalized to unit variance and the Euclidean distance of each
+#' sample to the centre of the data is computed, which is identical to the
+#' Mahalanobis distance \eqn{H}. Additionally, the Mahalanobis distances between
 #' samples are comptuted. The algorithm then proceeds as follows:
 #'
 #' \enumerate{
@@ -102,27 +101,27 @@
 #' cumulative sum of leverages of the points selected in each iteration. The
 #' theoretical cumulative sum of leverage is computed such as each point has the
 #' same leverage (the sum of leverages divided by the number of observations).
-#' The loop having the largest difference between the observed and theoretical 
-#' sums is considered as producing the optimal selection of points (the subset 
+#' The loop having the largest difference between the observed and theoretical
+#' sums is considered as producing the optimal selection of points (the subset
 #' that best reproduces the variability of the predictor space).
 #' @note The Puchwein algorithm is an iterative method and can be slow for large
 #' data matrices.
-#' @seealso \code{\link{kenStone}}, \code{\link{duplex}}, 
+#' @seealso \code{\link{kenStone}}, \code{\link{duplex}},
 #' \code{\link{shenkWest}}, \code{\link{honigs}}, \code{\link{naes}}
 #' @export
 
-puchwein <- function(X, 
+puchwein <- function(X,
                      pc = 0.95,
-                     k = 0.2, 
+                     k = 0.2,
                      min.sel = 5,
-                     details = FALSE, 
-                     .center = TRUE, 
+                     details = FALSE,
+                     .center = TRUE,
                      .scale = FALSE) {
   if (ncol(X) < 2) {
-    stop("X should have at least 2 columns")
+    stop("X must have at least 2 columns")
   }
   if (min.sel >= nrow(X)) {
-    stop("min.sel should be lower than nrow(X)")
+    stop("min.sel must be lower than nrow(X)")
   }
   if (!is.data.frame(X)) {
     X <- as.data.frame(X)
